#
# spec file for package isa-l
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           isa-l
Version:        2.31.1
Release:        1.2
Summary:        Intel Intelligent Storage Acceleration Library
Group:          Development/Libraries/C and C++
License:        BSD-3-Clause
URL:            https://github.com/intel/isa-l
Source:         https://github.com/intel/isa-l/archive/refs/tags/v%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc
BuildRequires:  libtool
BuildRequires:  nasm >= 2.13

%description
Optimized low-level functions targeting storage applications.

%package -n igzip
Summary:        gzip backed by the ISA-L deflate library
Group:          Productivity/Archiving/Compression

%description -n igzip
igzip compresses and decompresses files similar to gzip using the
ISA-L deflate library.

Output .gz files are compatible with gzip and RFC 1952.

%package devel
Summary:        Development files for the Intel Intelligent Storage Acceleration Library
Group:          Development/Libraries/C and C++
Requires:       libisal2 = %{version}

%description devel
ISA-L is a collection of optimized low-level functions targeting
storage applications.

This package contains the development headers for the library found
in libisal2.

%package -n libisal2
Summary:        Intel Intelligent Storage Acceleration Library
Group:          System/Libraries

%description -n libisal2
ISA-L is a collection of optimized low-level functions targeting
storage applications. ISA-L includes:

* Erasure codes: Block Reed-Solomon type erasure codes for any
  encode/decode matrix in GF(2^8).
* CRC Implementations of cyclic redundancy check. Six different
  polynomials supported: iscsi32, ieee32, t10dif, ecma64, iso64,
  jones64.
* RAID calculation and operation on XOR and P+Q parity found in
  common RAID implementations.
* Compression of deflate-compatible data compression.
* De-compression of inflate-compatible data compression.

This package contains the development headers for the library found
in libisal2.

%prep
%autosetup

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
./autogen.sh
%configure
%make_build

%install
%make_install

%ldconfig_scriptlets -n libisal2

%files -n igzip
%license LICENSE
%doc README.md
%{_bindir}/igzip
%{_mandir}/man1/igzip.1.gz

%files devel
%dir %{_includedir}/%{name}
%{_includedir}/%{name}.h
%{_includedir}/%{name}/crc.h
%{_includedir}/%{name}/crc64.h
%{_includedir}/%{name}/erasure_code.h
%{_includedir}/%{name}/gf_vect_mul.h
%{_includedir}/%{name}/igzip_lib.h
%{_includedir}/%{name}/mem_routines.h
%{_includedir}/%{name}/raid.h
%{_includedir}/%{name}/test.h
%{_libdir}/libisal.a
%{_libdir}/libisal.la
%{_libdir}/libisal.so
%{_libdir}/pkgconfig/libisal.pc

%files -n libisal2
%{_libdir}/libisal.so.2
%{_libdir}/libisal.so.2.0.31

%changelog
* Mon Jan 13 2025 Pablo de Lara Guarch <pablo.de.lara.guarch@intel.com>
- v2.31.1: Update
  - Fixed return type for PowerPC _gf_vect_mul_base function.
  - Fixed isal_deflate_icf_finish_lvl1 dispatcher for aarch64.
  - Fixed CRC compilation on aarch64.
  - Fixed MacOS-14 compilation.
  - Fixed MinGW build.
  - Fixed Clang compilation on igzip library on aarch64.
  - Fixed Windows build on erasure code performance applications.
  - Fixed compilation with YASM
* Thu Jun  6 2024 Andreas Schwab <schwab@suse.de>
- Add -ffat-lto-objects
* Tue Feb 27 2024 Jan Engelhardt <jengelh@inai.de>
- Let -devel subpackage use the SRPM base name.
- Use %%ldconfig_scriptlets.
- Description updates: meaningful description for the SRPM, neutral
  descriptions, trim duplication, give libisal2 a bulleted list.
* Mon Feb 26 2024 Jeff Mahoney <jeffm@suse.com> - v2.31.0
- v2.31.0: Update
  - gf_vect_mul_base() function now returns an integer, matching the return type of gf_vect_mul() function (not a breaking change).
  - Added compress/decompress with dictionary to perf test app.
  - Zlib header can be now created on the fly when starting the compression.
  - Added isal_zlib_hdr_init() function to initialize the zlib header to 0.
  - Optimized AVX implementation.
  - Added new AVX2 and AVX512 implementations.
  - Added new AVX512 and AVX2 implementations using GFNI instructions.
  - Added new SVE implementation.
  - Added new CRC64 Rocksoft algorithm.
  - CRC x86 implementations optimized using ternary logic instructions and
  - folding of bigger data on the last bytes.
  - CRC16 T10dif aarch64 implementation improved.
  - CRC aarch64 implementations optimized using XOR fusion feature.
  - Changed performance tests to warm by default.
  - Fixed various compilation issues/warnings for different platforms.
  - Fixed documentation on xor/pq gen/check functions, with minimum
    number of vectors.
  - Fixed potential out-of-bounds read on Adler32 Neon implementation.
  - Fixed potential out-of-bounds read on gf_vect_mul Neon implementation.
  - Fixed x86 load/store instructions in erasure coding functions (aligned moves
    that should be unaligned).
  - Fixed memory leaks in unit tests.
* Thu Mar 23 2023 Jeff Mahoney <jeffm@suse.com> - v2.30.0
- v2.30.0: Initial packaging.
